import axios from 'axios';

export interface MenuRecord {
  id?: number;
  pid?: number;
  name: string;
  path?: string;
  meta: {
    locale: string;
    title?: string;
    icon?: string;
    requiresAuth: boolean;
    hideInMenu: boolean;
    order: number;
    permissions: string[];
    showInMenu?: boolean;
    menuOrder?: number;
  };
  children?: MenuRecord[];
}

export interface MenuCreateRecord extends MenuRecord {
  type: string;
}
export interface MenuUpdateRecord {
  pid?: number;
  name: string;
  path: string;
  locale?: string;
  icon?: string;
  createTime?: string;
  createBy?: string;
  type: string;
  requiresAuth?: boolean;
  hideInMenu?: boolean;
  menuOrder?: number;
  permissions: string;
}

// 获取详情
export const queryMenuDetail = (id: string | number) => {
  return axios.get(`/api/rest/menu/${id}`);
};

export const queryMenuList = (data: string) => {
  return axios({
    url: '/api/rest/menu/tree',
    method: 'get',
    params: {
      name: data,
    },
  });
};

export const createMenu = (data: MenuCreateRecord) => {
  return axios.post('/api/rest/menu', data);
};

export const updateMenu = (data: MenuCreateRecord) => {
  return axios.patch(`/api/rest/menu/${data.id}`, data);
};

export const removeMenu = (id: string | number) => {
  return axios.delete(`/api/rest/menu/${id}`);
};
