import axios from 'axios';

export interface Attachment {
  id: string;
  fileName: string;
  mimeType: string;
  uploadTime: string;
  url: string;
}

export interface MessagesList {
  id?: number;
  userId?: number | null;
  user?: string | null;
  messageId?: number | null;
  message?: string | null;
  isRead?: boolean | null;
  readTime?: string | null;
  username?: string | null;
  name?: string | null;
  avatar?: string | null;
  address?: string | null;
  type?: string;
  system?: boolean;
  email?: boolean;
  sms?: boolean;
  html?: boolean;
  title?: string;
  content?: string;
  remark?: string;
  createTime?: string;
  createBy?: string;
  updateTime?: string;
  updateBy?: string;
  attachments?: Attachment[];
}

export interface MessagesRecord {
  userId?: string;
  title?: string;
  type?: string;
  name?: string;
  system?: number[];
  isRead?: boolean;
  createAtBegin?: string;
  createAtEnd?: string;
  current: number;
  size: number;
}

export interface MessageStatus {
  ids: number[];
}

export type MessageListType = MessagesList[];

// 查看详情
export function queryMessage(id: number) {
  return axios.get(`/api/rest/notice/self/${id}`);
}
// 分页查询
export function queryMessagesList(data: MessagesRecord) {
  return axios({
    url: '/api/rest/notice/self',
    method: 'get',
    params: data,
  });
}
// 未读消息数量
export function queryMessagesCount() {
  return axios.get('/api/rest/notice/count-unread');
}

// 已读消息数量
export function queryMessagesReadCount() {
  return axios.get('/api/rest/notice/acknowledge');
}

// 批量设置消息已读
export function setMessageStatus(data: MessageStatus) {
  return axios.patch<MessageListType>('/api/rest/notice/read', data);
}
