import { DEFAULT_LAYOUT } from '../base';
import { AppRouteRecordRaw } from '../types';

const IOT: AppRouteRecordRaw = {
  path: '/iot',
  name: 'iot',
  component: DEFAULT_LAYOUT,
  meta: {
    locale: '物联网管理',
    title: '物联网管理',
    icon: 'icon-empty',
    requiresAuth: true,
    order: 1,
    permissions: ['iot'],
  },
  children: [
    {
      path: 'product',
      name: 'Product',
      component: () => import('@/views/iot/product/index.vue'),
      meta: {
        locale: '产品管理',
        title: '产品管理',
        requiresAuth: true,
        permissions: ['iot:product'],
      },
    },
    {
      path: 'device',
      name: 'Device',
      component: () => import('@/views/iot/device/index.vue'),
      meta: {
        locale: '设备管理',
        title: '设备管理',
        requiresAuth: true,
        permissions: ['iot:device'],
      },
    },
    {
      path: 'deviceCard',
      name: 'DeviceCard',
      component: () => import('@/views/iot/deviceCard/index.vue'),
      meta: {
        locale: '设备管理(卡片)',
        title: '设备管理(卡片)',
        requiresAuth: true,
        permissions: ['iot:device'],
      },
    },
    {
      path: 'product/:id',
      name: 'productDetail',
      component: () =>
        import('@/views/iot/product/components/product-detail.vue'),
      meta: {
        locale: '产品详情',
        title: '产品详情',
        requiresAuth: true,
        showInMenu: false,
        permissions: ['iot:product:query'],
      },
    },
    {
      path: 'device/:id',
      name: 'deviceDetail',
      component: () =>
        import('@/views/iot/device/components/device-detail.vue'),
      meta: {
        locale: '设备详情',
        title: '设备详情',
        requiresAuth: true,
        showInMenu: false,
        permissions: ['iot:device:query'],
      },
    },
    {
      path: 'cardDevice/:id',
      name: 'cardDeviceDetail',
      component: () =>
        import('@/views/iot/deviceCard/components/device-detail.vue'),
      meta: {
        locale: '设备详情',
        title: '设备详情',
        requiresAuth: true,
        showInMenu: false,
        permissions: ['iot:device:query'],
      },
    },
    {
      path: 'product/tsl/:id',
      name: 'productTsl',
      component: () => import('@/views/iot/product/components/product-tsl.vue'),
      meta: {
        locale: '物模型',
        title: '物模型',
        requiresAuth: true,
        showInMenu: false,
        permissions: ['iot:tsl'],
      },
    },
  ],
};

export default IOT;
